@@ -1,5 +1,9 @@
 import snappi
 import snappi_trex
+import sys, os
+
+trex_path = '/opt/trex/v2.89/automation/trex_control_plane/interactive/trex-core/scripts/automation/trex_control_plane/interactive'
+sys.path.insert(0, os.path.abspath(trex_path))
 
 
 
